@@ -20,6 +20,7 @@ from suite_py.commands.project_lock import ProjectLock
 from suite_py.commands.rollback import Rollback
 from suite_py.commands.status import Status
 from suite_py.commands.aggregator import Aggregator
+from suite_py.commands.secret import Secret
 from suite_py.lib.config import Config
 from suite_py.lib.handler import git_handler as git
 from suite_py.lib.handler import prompt_utils
@@ -169,3 +170,13 @@ def cli_generator(obj):
 @click.pass_obj
 def cli_aggregator(obj, show_list, change):
     Aggregator(obj["config"], show_list, change).run()
+
+
+@main.command(
+    "secret", help="Manage secrets grants in multiple countries (aws-vault needed)"
+)
+@click.option("-c", "--create", "create_action", required=False, count=True)
+@click.option("-g", "--grant", "grant_action", required=False, count=True)
+@click.pass_obj
+def cli_secret(obj, create_action, grant_action):
+    Secret(obj["project"], obj["config"], create_action, grant_action).run()
